@@ -63,7 +63,6 @@ class TestCli(object):
             script=None,                            # 脚本文件名，None表示命令行模式
             commandMap=None,                        # SQL映射文件名，None表示不存在
             nologo=False,                           # 是否不打印登陆时的Logo信息，True的时候不打印
-            breakScenarioWithError=False,           # 遇到命令行错误，是否中断当前Scenario继续运行
             breakWithError=False,                   # 遇到命令行错误，是否中断脚本后续执行，立刻退出
             breakErrorCode=255,                     # 遇到命令行错误时候的退出代码
             xlog=None,                              # 扩展日志信息文件输出名，None表示不需要
@@ -80,7 +79,10 @@ class TestCli(object):
             casename=None,                          # 程序所在的CaseName
             namespace=None,                         # 程序的默认命名空间
     ):
+        self.Version = __version__                      # 当前程序版本
+
         self.db_saved_conn = {}                         # 数据库Session备份
+
         self.cmdMappingHandler = CmdMapping()           # 函数句柄，处理SQLMapping信息
         self.cmdExecuteHandler = CmdExecute()           # 函数句柄，具体来执行语句
         self.httpHandler = urllib3.PoolManager()        # Http请求线程池，用于处理API请求
@@ -93,14 +95,12 @@ class TestCli(object):
         self.appOptions = None                          # 应用程序的配置参数
         self.Encoding = None                            # 应用程序的Encoding信息
         self.prompt_app = None                          # PromptKit控制台
-        self.echofilename = None                        # 当前回显文件的文件名称
-        self.Version = __version__                      # 当前程序版本
+        self.ProcessPwd = os.getcwd()                   # 进程所在的目录
         self.xlogFile = None                            # xlog文件名
         self.xlogFileFullPath = None                    # xlog文件名-绝对路径
         self.xlogFileHandle = None                      # xlog文件句柄
         self.breakWithError = breakWithError            # 是否在遇到错误的时候退出
         self.breakErrorCode = breakErrorCode            # 遇到错误的退出代码
-        self.breakScenarioWithError = breakScenarioWithError  # 遇到命令行错误是否立刻退出当前Scenario的继续运行
 
         # 数据库连接的各种参数
         # 每次连接后需要保存这些变量，下次可以直接重新连接，如果不填写相关信息，则默认上次连接信息
@@ -117,6 +117,12 @@ class TestCli(object):
         self.db_service = None                          # 数据库连接服务
         self.db_parameters = None                       # 数据库连接额外参数
 
+        # 如果没有标准输出和标准错误输出，则不输出。不报错
+        if not sys.stdout.isatty():
+            sys.stdout = open(os.devnull, mode="w")
+        if not sys.stderr.isatty():
+            sys.stderr = open(os.devnull, mode="w")
+
         # NLS处理，设置字符集
         if clientCharset is not None:                   # 客户端脚本字符集
             self.testOptions.set("SCRIPT_ENCODING", clientCharset)
@@ -191,6 +197,7 @@ class TestCli(object):
         self.JobHandler.setProcessContextInfo("logon", self.logon)
         self.JobHandler.setProcessContextInfo("nologo", self.nologo)
         self.JobHandler.setProcessContextInfo("commandMap", self.commandMap)
+        self.JobHandler.setProcessContextInfo("processPwd", self.ProcessPwd)
         self.JobHandler.setProcessContextInfo("xlog", xlog)
         self.JobHandler.setProcessContextInfo("logfilename", self.logfilename)
         self.JobHandler.setProcessContextInfo("script", self.commandScript)
@@ -523,7 +530,7 @@ class TestCli(object):
                         if re.match(r'echo\s+off', p_result["message"], re.IGNORECASE):
                             # Echo Off这个语句，不打印到Echo文件中
                             m_EchoFlag = m_EchoFlag & ~OFLAG_ECHO
-                        if p_result["script"] is None:
+                        if p_result["script"] is None and sys.stdin.isatty():
                             # 控制台应用，不再打印SQL语句到控制台（因为用户已经输入了)
                             m_EchoFlag = m_EchoFlag & ~OFLAG_CONSOLE
                         self.echo(message, m_EchoFlag)
@@ -536,7 +543,7 @@ class TestCli(object):
                                 if p_result["rawCommand"]["name"] == "SPOOL":
                                     if p_result["rawCommand"]["file"].strip().upper() == "OFF":
                                         m_EchoFlag = m_EchoFlag & ~OFLAG_SPOOL
-                            if p_result["script"] == "Console":
+                            if p_result["script"] == "Console" and sys.stdin.isatty():
                                 # 控制台应用，不再打印SQL语句到控制台（因为用户已经输入了)
                                 m_EchoFlag = m_EchoFlag & ~OFLAG_CONSOLE
                             if p_result["formattedCommand"] is not None:
@@ -549,7 +556,10 @@ class TestCli(object):
                                     self.echo(message, m_EchoFlag)
                     elif p_result["type"] == "result":
                         title = p_result["title"]
-                        cur = p_result["rows"]
+                        if self.testOptions.get("TERMOUT").upper() == 'ON':
+                            cur = p_result["rows"]
+                        else:
+                            cur = []
                         headers = p_result["headers"]
                         columnTypes = p_result["columnTypes"]
                         status = p_result["status"]
@@ -654,7 +664,7 @@ class TestCli(object):
         # 如果运行在脚本方式下，不再调用PromptSession
         # 运行在无终端的模式下，也不会调用PromptSession
         # 对于脚本程序，在执行脚本完成后就会自动退出
-        if self.commandScript is None and not self.HeadlessMode:
+        if self.commandScript is None and not self.HeadlessMode and sys.stdin.isatty():
             # 如果可能，在用户的当前目录下生成sqlcli-history.txt隐含文件
             user_home = os.path.expanduser('~')
             m_HistoryFile = os.path.join(user_home, '.testcli-history.txt')
@@ -688,7 +698,7 @@ class TestCli(object):
                     raise EOFError
 
             # 开始依次处理控制台送来的语句
-            if not self.commandScript:
+            if not self.commandScript and sys.stdin.isatty():
                 while True:
                     # 循环从控制台读取命令
                     if not self.DoCommand():
@@ -696,18 +706,27 @@ class TestCli(object):
 
             # 如果传递的参数中有脚本文件，先执行脚本文件, 执行完成后自动退出
             try:
-                # 如果有脚本目录，则运行的时候切换到脚本所在的目录下，运行结束后要返回当前目录
-                currentPwd = os.getcwd()
-                scriptDir = os.path.dirname(str(self.commandScript))
-                scriptBase = os.path.basename(str(self.commandScript))
-                if scriptDir.strip() != "":
-                    # 如果脚本不是当前目录，需要切换到脚本目录下
-                    # 如果脚本是当前目录，切换到空目录会报错，所以不能切换
-                    os.chdir(scriptDir)
-                self.DoCommand(text='_start ' + scriptBase)
-                if scriptDir.strip() != "":
-                    # 如果发生了脚本切换，则执行脚本后要返回切换前的目录
-                    os.chdir(currentPwd)
+                if self.commandScript:
+                    # 如果有脚本目录，则运行的时候切换到脚本所在的目录下，运行结束后要返回当前目录
+                    currentPwd = os.getcwd()
+                    scriptDir = os.path.dirname(str(self.commandScript))
+                    scriptBase = os.path.basename(str(self.commandScript))
+                    if scriptDir.strip() != "":
+                        # 如果脚本不是当前目录，需要切换到脚本目录下
+                        # 如果脚本是当前目录，切换到空目录会报错，所以不能切换
+                        os.chdir(scriptDir)
+                    self.DoCommand(text='_start ' + scriptBase)
+                    if scriptDir.strip() != "":
+                        # 如果发生了脚本切换，则执行脚本后要返回切换前的目录
+                        os.chdir(currentPwd)
+                else:
+                    # 系统没有标准输入终端，那么从stdin中读取信息
+                    #  not sys.stdin.isatty()
+                    stdinCommand = ""
+                    if not sys.stdin.isatty():
+                        for line in sys.stdin:
+                            stdinCommand = stdinCommand + "\n" + line
+                    self.DoCommand(text=stdinCommand)
             except TestCliException:
                 raise EOFError
             self.DoCommand(text='_exit')
